.. _bluegraph_backends_networkx_ref:

`networkx` package
--------------------


Reference page for the `bluegraph.backends.networkx` package. All the interfaces below are also available as `bluegraph.backends.networkx.<interface>` (for example, :code:`from bluegraph.backends.networkx import NXPathFinder`).


Graph metrics
^^^^^^^^^^^^^

.. automodule:: bluegraph.backends.networkx.analyse.metrics
	:members:


Path search
^^^^^^^^^^^^^

.. automodule:: bluegraph.backends.networkx.analyse.paths
	:members:


Community Detection
^^^^^^^^^^^^^^^^^^^^

.. automodule:: bluegraph.backends.networkx.analyse.communities
	:members: